@@ -242,30 +242,30 @@ def getDBHostFromTransientName(SNNames):
 #          If no host is found, return None
 def getHostFromHostName(hostNames):
     fullTable = fullData()
-    hostName = np.array([re.sub(r"\s+", "", str(hostName)) for hostName in hostNames])
-    #allHosts = np.array([re.sub(r"\s+", "", str(x)) for x in fullTable['NED_name']])
-    for name in hostName:
+    possibleNames = []
+
+    for name in hostNames:
         possibleNames.append(name)
         possibleNames.append(name.upper())
+        possibleNames.append(re.sub(r"\s+", "", str(name)))
         possibleNames.append(name.lower())
 
     host = fullTable[fullTable['NED_name'].isin(possibleNames)]
-    if len(host) > 0
-        return host
-    else:
+    if host is None:
         print("Sorry, no hosts were found in our database!\n")
-        return None
+    return host
 
 def getHostFromHostCoords(hostCoords):
     fullTable = fullData()
     c2 = SkyCoord(fullTable['raMean']*u.deg, fullTable['decMean']*u.deg, frame='icrs')
-    host = None
+    host = []
     for hostCoord in hostCoords:
-        sep = np.array(hostCoords.separation(c2).arcsec)
+        sep = np.array(hostCoord.separation(c2).arcsec)
         if np.nanmin(sep) <= 1:
             host_idx = np.where(sep == np.nanmin(sep))[0][0]
             host.append(fullTable.iloc[[host_idx]])
-    if host is None:
+
+    if len(host) < 1:
         print("Sorry, No hosts found in our database!\n")
     else:
         host = pd.concat(host, ignore_index=True)
@@ -372,22 +372,25 @@ def getHostImage(transientName='', band="grizy", rad=60, save=0):
         print("Error! Please enter a supernova!\n")
         return
     fullTable = fullData()
-    host = getDBHostFromTransientName(transientName)
-    host.reset_index(drop=True, inplace=True)
-    tempSize = int(4*float(rad))
-    fn_save = host['objID'].values[0]
-    if np.unique(host['NED_name']) != "":
-        fn_save = host['NED_name'].values[0]
-        print("Showing postage stamp for %s"%np.unique(host['NED_name'])[0])
-    ra = np.unique(host['raMean'])[0]
-    dec = np.unique(host['decMean'])[0]
-    tempSize = int(4*rad)
-    img = getcolorim(ra, dec, output_size=tempSize, size=tempSize, filters=band, format="png")
-    plt.figure(figsize=(10,10))
-    plt.imshow(img)
-    if save:
-        img.save("%s.png" % fn_save)
-    return
+    host, notFound = getDBHostFromTransientName(transientName)
+    if host is not None:
+        host.reset_index(drop=True, inplace=True)
+        tempSize = int(4*float(rad))
+        fn_save = host['objID'].values[0]
+        if np.unique(host['NED_name']) != "":
+            fn_save = host['NED_name'].values[0]
+            print("Showing postage stamp for %s"%np.unique(host['NED_name'])[0])
+        ra = np.unique(host['raMean'])[0]
+        dec = np.unique(host['decMean'])[0]
+        tempSize = int(4*rad)
+        img = getcolorim(ra, dec, output_size=tempSize, size=tempSize, filters=band, format="png")
+        plt.figure(figsize=(10,10))
+        plt.imshow(img)
+        if save:
+            img.save("%s.png" % fn_save)
+        return
+    else:
+        print("Transient host not found!")
 
 # description
 # inputs
